@@ -20,12 +20,13 @@ sites = [
 
 
 class Virus():
+    """
+    This is the class Virus. Pretty basic stuff.
+    """
     def open_website(self, duration):
         t = 0
+        duration = duration*60
         while t <= duration:
             webbrowser.open(random.choice(sites))
             time.sleep(1)
             t += 1
-
-    def start(self, duration = 10): #Default site type is 'sfw' and duration is 10 minutes
-        open_website(duration*60)
